sphinx_basic_ng: Modern skeleton for Sphinx themes
==================================================

Description
-----------

Modern skeleton for Sphinx themes

License
-------

Upstream Contact
----------------

https://pypi.org/project/sphinx-basic-ng/

